:orphan:



.. _sphx_glr_auto_examples:

=========
Tutorials
=========

To learn how to use KLIFF, begin with the tutorials. The :ref:`tut_kim_sw` example
is a good entry point to see the basics of training a physics-motivated potential,
and the :ref:`tut_nn` example walks through the steps to train a machine-learning
neural network potential.



.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="In this tutorial, we train a linear regression model on the descriptors obtained using the symm...">

.. only:: html

    .. figure:: /auto_examples/images/thumb/sphx_glr_example_linear_regression_thumb.png

        :ref:`sphx_glr_auto_examples_example_linear_regression.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/example_linear_regression

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="In this tutorial, we train a Stillinger-Weber (SW) potential for silicon that is archived on Op...">

.. only:: html

    .. figure:: /auto_examples/images/thumb/sphx_glr_example_kim_SW_Si_thumb.png

        :ref:`sphx_glr_auto_examples_example_kim_SW_Si.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/example_kim_SW_Si

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="In this tutorial, we train a neural network (NN) potential for silicon">

.. only:: html

    .. figure:: /auto_examples/images/thumb/sphx_glr_example_nn_Si_thumb.png

        :ref:`sphx_glr_auto_examples_example_nn_Si.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/example_nn_Si
.. raw:: html

    <div style='clear:both'></div>



.. only :: html

 .. container:: sphx-glr-footer
    :class: sphx-glr-footer-gallery


  .. container:: sphx-glr-download

    :download:`Download all examples in Python source code: auto_examples_python.zip <//Users/Wenz/Applications/kliff/docs/source/auto_examples/auto_examples_python.zip>`



  .. container:: sphx-glr-download

    :download:`Download all examples in Jupyter notebooks: auto_examples_jupyter.zip <//Users/Wenz/Applications/kliff/docs/source/auto_examples/auto_examples_jupyter.zip>`


.. only:: html

 .. rst-class:: sphx-glr-signature

    `Gallery generated by Sphinx-Gallery <https://sphinx-gallery.github.io>`_
